cancel property

  1. @TagNumber.new(4)
bool get cancel

EXPERIMENTAL: When true, this is a cancel request, indicating that a previously sent WorkRequest with the same request_id should be cancelled. The arguments and inputs fields must be empty and should be ignored.

Implementation

@$pb.TagNumber(4)
$core.bool get cancel => $_getBF(3);
  1. @TagNumber.new(4)
set cancel (bool value)

Implementation

@$pb.TagNumber(4)
set cancel($core.bool value) => $_setBool(3, value);