inputs property
The inputs that the worker is allowed to read during execution of this request.
Implementation
@$pb.TagNumber(2)
$pb.PbList<Input> get inputs => $_getList(1);
The inputs that the worker is allowed to read during execution of this request.
@$pb.TagNumber(2)
$pb.PbList<Input> get inputs => $_getList(1);