IsolateDriverConnection class

DriverConnection that works with an isolate via a SendPort.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readResponse() → Future<WorkResponse>
override
toString() → String
A string representation of this object.
inherited
writeRequest(WorkRequest request) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(ReceivePort receivePort) → Future<IsolateDriverConnection>
Creates a driver connection for a worker in an isolate. Provide the receivePort attached to the SendPort that the isolate was created with.