TestWorkerConnection class abstract

Interface for a TestWorkerConnection which records its responses

Implemented types
Implementers

Constructors

TestWorkerConnection()

Properties

hashCode → int
The hash code for this object.
no setterinherited
responses → List<WorkResponse>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readRequest() → FutureOr<WorkRequest?>
Reads a WorkRequest or returns null if there are none left.
inherited
toString() → String
A string representation of this object.
inherited
writeResponse(WorkResponse response) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited