sandboxDir property
The relative directory inside the workers working directory where the
inputs and outputs are placed, for sandboxing purposes. For singleplex
workers, this is unset, as they can use their working directory as sandbox.
For multiplex workers, this will be set when the
--experimental_worker_multiplex_sandbox flag is set and the execution
requirements for the worker includes 'supports-multiplex-sandbox'.
The paths in inputs will not contain this prefix, but the actual files
will be placed/must be written relative to this directory. The worker
implementation is responsible for resolving the file paths.
Implementation
@$pb.TagNumber(6)
$core.String get sandboxDir => $_getSZ(5);
Implementation
@$pb.TagNumber(6)
set sandboxDir($core.String value) => $_setString(5, value);